<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>مراقب النظام</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>مراقب النظام هو أداة لمراقبة تحميل النظام في الوقت الفعلي، وعمليات العرض والتحكم، والخدمات التي تعمل على نظامك.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>إخفاء التفاصيل</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>الاستخدام الكلي</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>الاستخدام الفردي</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>قراءة</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>كتابة</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 ثانية </translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 أيام %2 ساعة %3 دقيقة</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>الاستخدام</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>التردد الحالي</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>التردد</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>بوكات</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>معالجات منطقية</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>الأفتراضية</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>كاش L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>كاش L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>كاش L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>كاش L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>معدل الحمل</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>التص jurوص الملف</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>العمليات</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>عنصر THREADS</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>اسم المستضيف</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>نوع نظام التشغيل</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>النسخة</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>وقت التشغيل</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 ثانية </translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>لا نتائج للبحث</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>تفاصيل</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>تفاصيل</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>نشط</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>إعادة التحميل</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>خامل</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>تفعيل</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>تعطيل</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>لم يتم العثور</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>إعدادات سيئة</translation>
    </message>
    <message>
        <source>error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>مدمج</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>مقتع</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>مُحمل</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>مفعل</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>معطل</translation>
    </message>
    <message>
        <source>static</source>
        <translation>ساكن</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>عابر</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>بشكل غير مباشر</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>مدة العرض مفعلة</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>مقتع</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>اُنشئت</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>مُنتهي</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>بدء قبل</translation>
    </message>
    <message>
        <source>start</source>
        <translation>بدء</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>بدء بعد</translation>
    </message>
    <message>
        <source>running</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>تم الخروج</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>إعادة التحميل</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>إيقاف</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>ايقاف جهاز المراقبة</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>ايقاف ميزة Sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>ايقاف ميزة Sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>ايقاف بعد</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>انهاء Sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>انهاء Sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>فشل</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>اعادة تشغيل تلقائية</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>استهلاك معالجك أعلى من %1%</translation>
    </message>
    <message>
        <source>Your memory usage is higher than %1%!</source>
        <translation>استهلاك пاومةك أعلى من %1%</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>المتاح</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>مشترك</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>محكم الصache</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>البوثرز</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>تبديل محكم الشايف</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>تفعيل</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>غير نشط</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>مشوه</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>مخرزا</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>إجمالي التبديل</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>空間交換</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>استل</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>النموذج</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>سرعة القراءة</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>سرعة الكتابة</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>السعة</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>اقرأ مجالات</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>قراءات في الثانية</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>مجالات قرأ في الثانية</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>/navbar-objects/merged- mũiٍ‏تم في الثانية</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>تم написة مجالات</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>الihnامات مكتملة</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>ال Writes مدمجة</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>كتابة في الثانية</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>مجالات مكتوبة في الثانية</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>ال نُسخة مدمجة في الثانية</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>موافق</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>النظام</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>عرض الاختصارات</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>قد يؤدي إنهاء هذه العملية إلى فقدان البيانات
هل أنت متأكد من المتابعة؟</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>إنهاء العملية</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>قد يؤدي فرض إنهاء هذه العملية إلى فقدان البيانات
هل أنت متأكد من المتابعة؟</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>قد يؤدي فرض إنهاء هذا التطبيق إلى فقدان البيانات
هل أنت متأكد من المتابعة؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>انهاء اجباري</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>انهاء</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>الحجم</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>عنوان بروتوكول الإنترنت (IP)</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>خمار الشبكة:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>تنقل:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>الحctime:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>معرض:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>نوع الإتصال</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>اسم مجموعة الشبكة</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>جودة الإتصال</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>قوة الإشارة</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>مستوى الضوضاء</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>العنوان المتميّز لظلال الكابلات</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>عرض النطاق الترددي</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>بركات المدخلات</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>بايتس المدخل</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>أخطاء المدخل</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>تخلى عن المدخل</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>التجاوزات على المدخل</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>مرamesة وردت</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>تذاكر إرسال</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>بتات إرسال</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>خطايات إرسال</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation> crossings إرسال</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>محرِّر إرسال</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>تذاكر محذوفة إرسال</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>سطر الأوامر</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>وقت البدء</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>اختر التطبيق الذي تودُ انهاءهُ</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>المستلم</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>المعالج</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>القراءة من القرص</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>الكتابة على القرص</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>ذاكرة التبديل</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>غير مفعل</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>التنزيل</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>الرفع</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>التلقي الإجمالي</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>الإرسال الإجمالي</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>المرسل</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>الأقراص</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>تحميل</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>مرتفع جداً</translation>
    </message>
    <message>
        <source>High</source>
        <translation>مرتفع</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>طبيعي</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>منخفض</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>منخفض جداً</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>مخصص</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>غير صالح</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, خطأ: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>فشل في تغيير أولوية العملية</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>التطبيقات</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>عملياتي</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>جميع العمليات</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>فشل في ايقاف العملية</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>فشل في استئناف العملية</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>فشل في قتل العملية</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>خطأ غير معروف</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>فشل في إرسال إشارة للمعالجة</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>فشل إنهاء عملية</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 من التطبيقات و 2% من العملبات قيد التشغيل)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>لا استجابة</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>تعليق</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>طبق النظام</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>عرض موقع الأوامر</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>الخصائص</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>إنهاء العملية</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>استئناف العملية</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>قتل العملية</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>تغيير الأولوية</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>تعليق العملية</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>أولوية مخصصة</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>تغيير</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>المعالج</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>الذاكرة</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>الكتابة على القرص</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>القراءة من القرص</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>التنزيل</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>الرفع</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>أولوية</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>الذاكرة المشتركة</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>الذاكرة الإفتراضية </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>غير مدعوم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>حماية النظام</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>إظهار التنبيهات عندما تتجاوز الاستخدام المعايير</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>حد_warنات CPU (%) </translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>حد_warنات الذاكرة (%) </translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>ص_majorنح Warning (دقائق</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>التنبيهات</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>فشل تعيين نوع بدء تشغيل الخدمة</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>خطأ: فشل تعيين نوع بدء تشغيل الخدمة بسبب تعطل العملية الفرعية.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>اسم مثيل الخدمة</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>بدء</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>إيقاف</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>إعادة البدء</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>يدوي</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>نوع بدء التشغيل</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>تحميل</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="vanished">تفعيل</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>فرعي</translation>
    </message>
    <message>
        <source>State</source>
        <translation type="vanished">حالة</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>نوع بدء التشغيل</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation>حالة البدء</translation>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation>technique البدء</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(قابل للتغيير</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>م范畴: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>فرض إنهاء التطبيق</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>توسيع</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>دمج</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>العمليات</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>الخدمات</translation>
    </message>
    <message>
        <source>Users</source>
        <translation>المستخدمون </translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <source>Administrator</source>
        <translation>المسؤول</translation>
    </message>
    <message>
        <source>Standard User</source>
        <translation>المستخدم الإفتراضي</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <source>Edit account information</source>
        <translation>تعديل معلومات الحساب</translation>
    </message>
</context>
</TS>